Blob Blame History Raw
--- cups-1.2.7/scheduler/ipp.c.driverd-timeout	2006-11-22 10:41:28.000000000 +0000
+++ cups-1.2.7/scheduler/ipp.c	2006-11-22 10:45:55.000000000 +0000
@@ -4175,7 +4175,7 @@
   close(temppipe[1]);
 
  /*
   * Wait up to 30 seconds for the PPD file to be copied...
   */
 
   total = 0;
@@ -4196,7 +4196,7 @@
     FD_SET(temppipe[0], input);
     FD_SET(CGIPipes[0], input);
 
-    timeout.tv_sec  = 30;
+    timeout.tv_sec  = 70;
     timeout.tv_usec = 0;
 
     if ((i = select(maxfd, input, NULL, NULL, &timeout)) < 0)
@@ -4175,7 +4175,7 @@
 
  /*
-  * Wait up to 30 seconds for the PPD file to be copied...
+  * Wait up to 70 seconds for the PPD file to be copied...
   */
 